Obscurations
============

.. autoclass:: batoid.Obscuration
    :members:

.. autoclass:: batoid.ObscCircle
    :show-inheritance:
    :members:

.. autoclass:: batoid.ObscAnnulus
    :show-inheritance:
    :members:

.. autoclass:: batoid.ObscRectangle
    :show-inheritance:
    :members:

.. autoclass:: batoid.ObscRay
    :show-inheritance:
    :members:

.. autoclass:: batoid.ObscNegation
    :show-inheritance:
    :members:

.. autoclass:: batoid.ObscUnion
    :show-inheritance:
    :members:

.. autoclass:: batoid.ObscIntersection
    :show-inheritance:
    :members:
